summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/utils.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kexi/formeditor/utils.h
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kexi/formeditor/utils.h')
-rw-r--r--kexi/formeditor/utils.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/formeditor/utils.h b/kexi/formeditor/utils.h
index 5107b45c..d6d56acb 100644
--- a/kexi/formeditor/utils.h
+++ b/kexi/formeditor/utils.h
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeChildrenFromList(WidgetList &list);
/*! This helper function install an event filter on \a object and all of its
- tqchildren, directed to \a container.
+ children, directed to \a container.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void installRecursiveEventFilter(TQObject *object, TQObject *container);
/*! This helper function removes an event filter installed before
- on \a object and all of its tqchildren.
+ on \a object and all of its children.
This is necessary to filter events for composed widgets. */
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
/*! \return the size of \a w tqchildren. This can be used eg to get widget's sizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}
@@ -94,18 +94,18 @@ class VerWidgetList : public WidgetList
KFORMEDITOR_EXPORT void removeRecursiveEventFilter(TQObject *object, TQObject *container);
KFORMEDITOR_EXPORT void setRecursiveCursor(TQWidget *w, Form *form);
-/*! \return the size of \a w tqchildren. This can be used eg to get widget's sizeHint. */
+/*! \return the size of \a w children. This can be used eg to get widget's sizeHint. */
KFORMEDITOR_EXPORT TQSize getSizeFromChildren(TQWidget *widget, const char *inheritClass=TQWIDGET_OBJECT_NAME_STRING);
}